import * as i0 from '@angular/core';
import { inject, Directive } from '@angular/core';
import { TranslationStore } from '@smallstack/i18n-components';
import { filterNullish, distinctUntilChangedObj } from '@smallstack/utils';
import { BaseWidgetComponent, FormService } from '@smallstack/widget-core';
import { map, switchMap, combineLatest, filter, firstValueFrom } from 'rxjs';

class InputBaseWidgetComponent extends BaseWidgetComponent {
    constructor() {
        super(...arguments);
        this.formService = inject(FormService);
        this.translationStore = inject(TranslationStore);
        this.path$ = this.data$.pipe(map((data) => data.path));
        this.schema$ = this.path$.pipe(filterNullish(), switchMap((path) => this.formService.getSchemaForPath$(path)), distinctUntilChangedObj());
        /** value of the form field */
        this.value$ = this.path$.pipe(filterNullish(), switchMap((path) => combineLatest([this.formService.getValueByPath$(path), this.schema$]).pipe(filter(([, schema]) => schema !== undefined), distinctUntilChangedObj(), switchMap(async ([val, schema]) => {
            if (val !== undefined)
                return val;
            else if (schema?.default !== undefined) {
                // set the value in model
                await this.setValue(schema.default);
                return schema.default;
            }
            return undefined;
        }))));
        this.required$ = this.path$.pipe(switchMap((path) => this.formService.isRequired$(path)));
        this.placeholder$ = this.schema$.pipe(map((schema) => schema?.["x-schema-form"]?.["placeholder"] || ""));
        this.validationErrors$ = this.path$.pipe(switchMap((path) => this.formService.getValidationStatusForPath$(path)));
        this.validationErrorText$ = this.validationErrors$.pipe(map((errors) => errors?.length > 0
            ? errors
                .map((inputWidgetError) => this.translationStore.translate(inputWidgetError.error.key, {
                replacers: inputWidgetError.error.replacers,
                showMissingKey: true,
                showFallback: true
            }))
                .join(", ")
            : undefined));
        this.options$ = combineLatest([
            this.formService.globalFormOptions$,
            this.data$.pipe(map((data) => data.options))
        ]).pipe(map(([globalFormOptions, options]) => ({ ...globalFormOptions, ...options })));
    }
    async setValue(value) {
        this.formService.setValueByPath(await firstValueFrom(this.path$), value);
    }
    /** Triggers the validation for this input widget if options.validateOn === "onBlur" */
    async validateOnBlur() {
        const options = await firstValueFrom(this.options$);
        const path = await firstValueFrom(this.path$);
        if (options?.validateOn === "blur")
            await this.formService.validateByPath(path);
    }
    /** Triggers the validation for this input widget if options.validateOn === "onBlur" */
    async validateOnChange() {
        const options = await firstValueFrom(this.options$);
        const path = await firstValueFrom(this.path$);
        if (options?.validateOn === "change" || this.formService.hasBeenValidated(path))
            await this.formService.validateByPath(path);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: InputBaseWidgetComponent, deps: null, target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.8", type: InputBaseWidgetComponent, usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: InputBaseWidgetComponent, decorators: [{
            type: Directive
        }] });

export { InputBaseWidgetComponent as I };
//# sourceMappingURL=smallstack-form-widgets-input-base-widget.component-e4949b87.mjs.map
