import { JsonPipe } from '@angular/common';
import * as i0 from '@angular/core';
import { Component, ChangeDetectionStrategy } from '@angular/core';
import * as i1 from '@angular/forms';
import { FormsModule } from '@angular/forms';
import { RxLet } from '@rx-angular/template/let';
import { RxPush } from '@rx-angular/template/push';
import { OverlayComponent, CloseDropDownOnClickDirective, DebugComponentComponent } from '@smallstack/common-components';
import { filterNullish, distinctUntilChangedObj, isNonEmptyString } from '@smallstack/utils';
import { BehaviorSubject, combineLatest, map } from 'rxjs';
import { F as FilterBaseWidgetComponent } from './smallstack-form-widgets-filter-base-widget.component-bc2d9350.mjs';
import '@smallstack/widget-core';
import 'uuid';

class StringFilterWidgetComponent extends FilterBaseWidgetComponent {
    constructor() {
        super();
        this.inputValue$ = new BehaviorSubject("");
        this.filterType$ = new BehaviorSubject("contains");
        this.unboxedFilterValue$ = combineLatest([this.value$, this.path$]).pipe(map(([value, path]) => (value ? value[path] : undefined)), map((value) => value ? (value.$regex instanceof RegExp ? value.$regex.source?.replace(/\.\*/g, "") : value) : undefined));
        this.subscribeToChanges();
    }
    subscribeToChanges() {
        this.subscription.add(combineLatest([this.inputValue$, this.filterType$, this.path$])
            .pipe(filterNullish(), distinctUntilChangedObj(), map(([value, type, path]) => {
            if (isNonEmptyString(value)) {
                if (type === "contains") {
                    void this.setFilter({ [path]: { $regex: new RegExp(".*" + value + ".*", "i") } });
                }
                else if (type === "exact") {
                    void this.setFilter({ [path]: value });
                }
            }
            else
                void this.setFilter(undefined);
        }))
            .subscribe());
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: StringFilterWidgetComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.8", type: StringFilterWidgetComponent, isStandalone: true, selector: "smallstack-string-filter-widget", usesInheritance: true, ngImport: i0, template: "<div class=\"join w-full\">\n  <div class=\"join-item\">\n    <label\n      *rxLet=\"filterType$; let filterType\"\n      class=\"btn btn-primary rounded-r-none !font-bold !text-lg\"\n      tabindex=\"-1\"\n      (click)=\"overlay.openOverlay()\"\n    >\n      {{ filterType === \"contains\" ? \"\u22C6\" : \"=\" }}\n    </label>\n    <smallstack-overlay #overlay [hasBackdrop]=\"false\">\n      <div class=\"input-dropdown\">\n        <ul class=\"menu menu-sm w-64\">\n          <li class=\"menu-title\">Filter Modus</li>\n          <li (click)=\"filterType$.next('contains'); overlay.closeOverlay()\">\n            <a\n              ><span class=\"font-extrabold text-xl rounded-box border input-bordered w-7 text-center\">\u22C6</span>\n              enth\u00E4lt</a\n            >\n          </li>\n          <li (click)=\"filterType$.next('exact'); overlay.closeOverlay()\">\n            <a\n              ><span class=\"font-extrabold text-xl rounded-box border input-bordered w-7 text-center\">=</span> stimmt\n              exakt \u00FCberein</a\n            >\n          </li>\n        </ul>\n      </div>\n    </smallstack-overlay>\n  </div>\n  <input\n    type=\"search\"\n    class=\"input input-bordered w-full join-item\"\n    [ngModel]=\"unboxedFilterValue$ | push\"\n    (ngModelChange)=\"inputValue$.next($event)\"\n  />\n</div>\n", dependencies: [{ kind: "pipe", type: RxPush, name: "push" }, { kind: "directive", type: RxLet, selector: "[rxLet]", inputs: ["rxLet", "rxLetStrategy", "rxLetComplete", "rxLetError", "rxLetSuspense", "rxLetContextTrigger", "rxLetCompleteTrigger", "rxLetErrorTrigger", "rxLetSuspenseTrigger", "rxLetNextTrigger", "rxLetRenderCallback", "rxLetParent", "rxLetPatchZone"], outputs: ["rendered"] }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: OverlayComponent, selector: "smallstack-overlay", inputs: ["hasBackdrop"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: StringFilterWidgetComponent, decorators: [{
            type: Component,
            args: [{ selector: "smallstack-string-filter-widget", standalone: true, changeDetection: ChangeDetectionStrategy.OnPush, imports: [
                        RxPush,
                        RxLet,
                        FormsModule,
                        CloseDropDownOnClickDirective,
                        JsonPipe,
                        OverlayComponent,
                        DebugComponentComponent
                    ], template: "<div class=\"join w-full\">\n  <div class=\"join-item\">\n    <label\n      *rxLet=\"filterType$; let filterType\"\n      class=\"btn btn-primary rounded-r-none !font-bold !text-lg\"\n      tabindex=\"-1\"\n      (click)=\"overlay.openOverlay()\"\n    >\n      {{ filterType === \"contains\" ? \"\u22C6\" : \"=\" }}\n    </label>\n    <smallstack-overlay #overlay [hasBackdrop]=\"false\">\n      <div class=\"input-dropdown\">\n        <ul class=\"menu menu-sm w-64\">\n          <li class=\"menu-title\">Filter Modus</li>\n          <li (click)=\"filterType$.next('contains'); overlay.closeOverlay()\">\n            <a\n              ><span class=\"font-extrabold text-xl rounded-box border input-bordered w-7 text-center\">\u22C6</span>\n              enth\u00E4lt</a\n            >\n          </li>\n          <li (click)=\"filterType$.next('exact'); overlay.closeOverlay()\">\n            <a\n              ><span class=\"font-extrabold text-xl rounded-box border input-bordered w-7 text-center\">=</span> stimmt\n              exakt \u00FCberein</a\n            >\n          </li>\n        </ul>\n      </div>\n    </smallstack-overlay>\n  </div>\n  <input\n    type=\"search\"\n    class=\"input input-bordered w-full join-item\"\n    [ngModel]=\"unboxedFilterValue$ | push\"\n    (ngModelChange)=\"inputValue$.next($event)\"\n  />\n</div>\n" }]
        }], ctorParameters: function () { return []; } });

export { StringFilterWidgetComponent };
//# sourceMappingURL=smallstack-form-widgets-string-filter-widget.component-14c81961.mjs.map
